@@ -1,5 +1,5 @@
 /* GDA common library
- * Copyright (C) 1998 - 2004 The GNOME Foundation.
+ * Copyright (C) 1998 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -110,7 +110,7 @@ void                          gda_data_model_thaw                   (GdaDataMode
 
 gint                          gda_data_model_get_n_rows             (GdaDataModel *model);
 gint                          gda_data_model_get_n_columns          (GdaDataModel *model);
-GdaColumn *gda_data_model_describe_column        (GdaDataModel *model, gint col);
+GdaColumn                    *gda_data_model_describe_column        (GdaDataModel *model, gint col);
 const gchar                  *gda_data_model_get_column_title       (GdaDataModel *model, gint col);
 void                          gda_data_model_set_column_title       (GdaDataModel *model, gint col, const gchar *title);
 gint                          gda_data_model_get_column_position    (GdaDataModel *model, const gchar *title);
@@ -135,10 +135,12 @@ gboolean                      gda_data_model_begin_update           (GdaDataMode
 gboolean                      gda_data_model_cancel_update          (GdaDataModel *model);
 gboolean                      gda_data_model_commit_update          (GdaDataModel *model);
 
-gchar                        *gda_data_model_to_comma_separated     (GdaDataModel *model);
-gchar                        *gda_data_model_to_tab_separated       (GdaDataModel *model);
-gchar                        *gda_data_model_to_xml                 (GdaDataModel *model, gboolean standalone);
-xmlNodePtr                    gda_data_model_to_xml_node            (GdaDataModel *model, const gchar *name);
+gchar                        *gda_data_model_to_text_separated      (GdaDataModel *model, const gint *cols, gint nb_cols,
+								     gchar sep);
+gchar                        *gda_data_model_to_xml                 (GdaDataModel *model, const gint *cols, gint nb_cols,
+								     const gchar *name);
+xmlNodePtr                    gda_data_model_to_xml_node            (GdaDataModel *model, const gint *cols, gint nb_cols, 
+								     const gchar *name);
 gboolean                      gda_data_model_add_data_from_xml_node (GdaDataModel *model, xmlNodePtr node);
 
 const gchar                  *gda_data_model_get_command_text       (GdaDataModel *model);
@@ -146,6 +148,9 @@ gboolean                      gda_data_model_set_command_text       (GdaDataMode
 GdaCommandType                gda_data_model_get_command_type       (GdaDataModel *model);
 gboolean                      gda_data_model_set_command_type       (GdaDataModel *model, GdaCommandType type);
 
+void                          gda_data_model_dump                   (GdaDataModel *model, FILE *to_stream);
+gchar                        *gda_data_model_dump_as_string         (GdaDataModel *model);
+
 G_END_DECLS
 
 #endif
