@@ -1,5 +1,5 @@
 /* GDA MySQL provider
- * Copyright (C) 1998-2005 The GNOME Foundation.
+ * Copyright (C) 1998 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *      Michael Lausch <michael@lausch.at>
@@ -60,9 +60,14 @@ static gboolean gda_mysql_provider_change_database (GdaServerProvider *provider,
 		                                    GdaConnection *cnc,
 		                                    const gchar *name);
 
+static gchar *gda_mysql_provider_get_specs_create_database (GdaServerProvider *provider);
+
 static gboolean gda_mysql_provider_create_database (GdaServerProvider *provider,
-						    GdaConnection *cnc,
-						    const gchar *name);
+						    GdaParameterList *params, GError **error);
+
+static gboolean gda_mysql_provider_create_database_cnc (GdaServerProvider *provider,
+						        GdaConnection *cnc,
+						        const gchar *name);
 
 static gboolean gda_mysql_provider_drop_database (GdaServerProvider *provider,
 						  GdaConnection *cnc,
@@ -118,11 +123,11 @@ static GdaDataModel *gda_mysql_provider_get_schema (GdaServerProvider *provider,
 						    GdaConnection *cnc,
 						    GdaConnectionSchema schema,
 						    GdaParameterList *params);
-
-static gchar *gda_mysql_provider_value_to_sql_string (GdaServerProvider *provider,
+gchar *gda_mysql_provider_value_to_sql_string (GdaServerProvider *provider,
 						  GdaConnection *cnc,
 						  GdaValue *from);
 
+
 static GObjectClass *parent_class = NULL;
 
 /*
@@ -144,7 +149,9 @@ gda_mysql_provider_class_init (GdaMysqlProviderClass *klass)
 	provider_class->get_server_version = gda_mysql_provider_get_server_version;
 	provider_class->get_database = gda_mysql_provider_get_database;
 	provider_class->change_database = gda_mysql_provider_change_database;
-	provider_class->create_database = gda_mysql_provider_create_database;
+	provider_class->get_specs_create_database = gda_mysql_provider_get_specs_create_database;
+	provider_class->create_database_params = gda_mysql_provider_create_database;
+	provider_class->create_database_cnc = gda_mysql_provider_create_database_cnc;
 	provider_class->drop_database = gda_mysql_provider_drop_database;
 	provider_class->create_table = gda_mysql_provider_create_table;
 	provider_class->drop_table = gda_mysql_provider_drop_table;
@@ -218,8 +225,71 @@ gda_mysql_provider_get_version (GdaServerProvider *provider)
 	return PACKAGE_VERSION;
 }
 
+/* generic function to open a MYSQL connection */
+static MYSQL *
+real_open_connection (const gchar *host, gint port, const gchar *socket,
+		      const gchar *db,
+		      const gchar *login, const gchar *password, 
+		      gboolean usessl, GError **error)
+{
+	MYSQL *mysql;
+	MYSQL *mysql_ret;
+	unsigned int mysqlflags = 0;
+#if MYSQL_VERSION_ID < 32200
+        gint err;
+#endif
+	
+	/* we can't have both a host/pair AND a unix_socket */
+        if ((host || (port >= 0)) && socket) {
+                g_set_error (error, 0, 0,
+			     _("You cannot provide a UNIX SOCKET if you also provide"
+			       " either a HOST or a PORT."));
+                return NULL;
+        }
+
+	/* provide the default of localhost:3306 if neither is provided */
+	if (!socket) {
+		if (!host)
+			host = "localhost";
+		else if (port <= 0)
+			port = 3306;
+	}
+
+	if (usessl)
+		 mysqlflags |= CLIENT_SSL;
+
+	mysql = g_new0 (MYSQL, 1);
+        mysql_init (mysql);
+        mysql_ret = mysql_real_connect (mysql, host, login, password,
+#if MYSQL_VERSION_ID >= 32200
+					db,
+#endif
+					port > 0? port : 0,
+					socket,
+					mysqlflags);
+	
+	
+	if (!mysql_ret) {
+		g_set_error (error, 0, 0, mysql_error (mysql));
+		g_free (mysql);
+		return NULL;
+	}
+	
+#if MYSQL_VERSION_ID < 32200
+	err = mysql_select_db (mysql, db);
+	if (err != 0) {
+		g_set_error (error, 0, 0, mysql_error (mysql))
+			mysql_close (mysql);
+		
+		return NULL;
+	}
+#endif
+	
+	return mysql;
+}
+
 /* open_connection handler for the GdaMysqlProvider class */
-static gboolean
+static 
 gda_mysql_provider_open_connection (GdaServerProvider *provider,
 				    GdaConnection *cnc,
 				    GdaQuarkList *params,
@@ -234,11 +304,10 @@ gda_mysql_provider_open_connection (GdaServerProvider *provider,
         const gchar *t_unix_socket = NULL;
         const gchar *t_use_ssl = NULL;
 	unsigned int mysqlflags = 0;
+
 	MYSQL *mysql;
-#if MYSQL_VERSION_ID < 32200
-        gint err;
-#endif
 	GdaError *error;
+	GError *gerror = NULL;
 	GdaMysqlProvider *myprv = (GdaMysqlProvider *) provider;
 
 	g_return_val_if_fail (GDA_IS_MYSQL_PROVIDER (myprv), FALSE);
@@ -258,51 +327,19 @@ gda_mysql_provider_open_connection (GdaServerProvider *provider,
 	if (password && *password != '\0')
 		t_password = password;
 
-	if (t_use_ssl && atoi (t_use_ssl) == 1)
-		mysqlflags |= CLIENT_SSL;
-
-	/* we can't have both a host/pair AND a unix_socket */
-	if ((t_host || t_port) && t_unix_socket) {
-		gda_connection_add_error_string (
-			cnc, _("You cannot provide a UNIX_SOCKET if you also provide"
-			       " either a HOST or a PORT."));
-		return FALSE;
-	}
-
-	/* provide the default of localhost:3306 if neither is provided */
-	if (!t_unix_socket) {
-		if (!t_host)
-			t_host = "localhost";
-		else if (!t_port)
-			t_port = "3306";
-	}
-	
-	mysql = g_new0 (MYSQL, 1);
-	mysql_init (mysql);
-	mysql = mysql_real_connect (mysql, t_host, t_user, t_password,
-#if MYSQL_VERSION_ID >= 32200
-				    t_db,
-#endif
-				    t_port ? atoi (t_port) : 0,
-				    t_unix_socket,
-				    mysqlflags);
+	mysql = real_open_connection (t_host, t_port ? atoi (t_port) : 0, t_unix_socket,
+				      t_db, t_user, t_password, t_use_ssl ? TRUE : FALSE, &gerror);
 	if (!mysql) {
-		error = gda_mysql_make_error (mysql);
+		error = gda_error_new ();
+		gda_error_set_description (error, gerror && gerror->message ? 
+					   gerror->message : "NO DESCRIPTION");
+                gda_error_set_number (error, gerror ? gerror->code : -1);
+		if (gerror)
+			g_error_free (gerror);
 		gda_connection_add_error (cnc, error);
 
 		return FALSE;
 	}
-#if MYSQL_VERSION_ID < 32200
-	err = mysql_select_db (mysql, t_db);
-	if (err != 0) {
-		error = gda_mysql_make_error (mysql);
-		mysql_close (mysql);
-		gda_connection_add_error (cnc, error);
-
-		return FALSE;
-	}
-#endif
-
 	g_object_set_data (G_OBJECT (cnc), OBJECT_DATA_MYSQL_HANDLE, mysql);
 
 	return TRUE;
@@ -463,11 +500,126 @@ gda_mysql_provider_change_database (GdaServerProvider *provider,
 
 }
 
+/* get_specs_create_database handler for the GdaMysqlProvider class */
+static gchar *
+gda_mysql_provider_get_specs_create_database (GdaServerProvider *provider)
+{
+	gchar *specs, *file;
+        gint len;
+	GdaMysqlProvider *myprv = (GdaMysqlProvider *) provider;
+
+	g_return_val_if_fail (GDA_IS_MYSQL_PROVIDER (myprv), FALSE);
+
+        file = g_build_filename (LIBGDA_DATA_DIR, "mysql_specs_create_db.xml", NULL);
+        if (g_file_get_contents (file, &specs, &len, NULL))
+                return specs;
+        else
+                return NULL;
+}
+
+#define string_from_string_param(param) \
+	(param && gda_parameter_get_value (param) && !gda_value_is_null (gda_parameter_get_value (param))) ? \
+	gda_value_get_string (gda_parameter_get_value (param)) : NULL
+
+#define int_from_int_param(param) \
+	(param && gda_parameter_get_value (param) && !gda_value_is_null (gda_parameter_get_value (param))) ? \
+	gda_value_get_integer (gda_parameter_get_value (param)) : -1
+
+#define bool_from_bool_param(param) \
+	(param && gda_parameter_get_value (param) && !gda_value_is_null (gda_parameter_get_value (param))) ? \
+	gda_value_get_boolean (gda_parameter_get_value (param)) : FALSE
+
 /* create_database handler for the GdaMysqlProvider class */
 static gboolean
 gda_mysql_provider_create_database (GdaServerProvider *provider,
-				    GdaConnection *cnc,
-				    const gchar *name)
+				    GdaParameterList *params, GError **error)
+{
+	GdaMysqlProvider *myprv = (GdaMysqlProvider *) provider;
+	MYSQL *mysql;
+	int res;
+	gboolean retval = TRUE;
+	GdaParameter *param = NULL;
+	GString *string;
+	
+	const gchar *login = NULL;
+	const gchar *password = NULL;
+	const gchar *host = NULL;
+	gint         port = -1;
+	const gchar *socket = NULL;
+	gboolean     usessl = FALSE;
+	const gchar *dbname = NULL;
+	const gchar *encoding = NULL;
+	const gchar *collate = NULL;
+
+
+	g_return_val_if_fail (GDA_IS_MYSQL_PROVIDER (myprv), FALSE);
+	
+	if (params) {
+		param = gda_parameter_list_find (params, "HOST");
+		host = string_from_string_param (param);
+
+		param = gda_parameter_list_find (params, "PORT");
+		port = int_from_int_param (param);
+
+		param = gda_parameter_list_find (params, "UNIX_SOCKET");
+		socket = string_from_string_param (param);
+
+		param = gda_parameter_list_find (params, "USE_SSL");
+		usessl = bool_from_bool_param (param);
+		
+		param = gda_parameter_list_find (params, "DATABASE");
+		dbname = string_from_string_param (param);
+
+		param = gda_parameter_list_find (params, "ENCODING");
+		encoding = string_from_string_param (param);
+
+		param = gda_parameter_list_find (params, "COLLATE");
+		collate = string_from_string_param (param);
+
+		param = gda_parameter_list_find (params, "ADM_LOGIN");
+		login = string_from_string_param (param);
+		
+		param = gda_parameter_list_find (params, "ADM_PASSWORD");
+		password = string_from_string_param (param);
+	}
+	if (!dbname) {
+		g_set_error (error, 0, 0,
+			     _("Missing parameter 'DATABASE'"));
+		return FALSE;
+	}
+
+	mysql = real_open_connection (host, port, socket,
+				      "mysql", login, password, usessl, error);
+	if (!mysql)
+		return FALSE;
+
+	/* Ask to create a database */
+	string = g_string_new ("CREATE DATABASE ");
+	g_string_append (string, dbname);
+	if (encoding)
+		g_string_append_printf (string, " CHARACTER SET %s", encoding);
+	if (collate)
+		g_string_append_printf (string, " COLLATE %s", collate);
+
+	res = mysql_query (mysql, string->str);
+	g_string_free (string, TRUE);
+
+	if (res) {
+		g_set_error (error, 0, 0, mysql_error (mysql));
+		retval = FALSE;
+	}
+	
+	mysql_close (mysql);
+
+	return retval;
+}
+
+
+/* create_database_cnc handler for the GdaMysqlProvider class */
+static gboolean
+gda_mysql_provider_create_database_cnc (GdaServerProvider *provider,
+				        GdaConnection *cnc,
+				        const gchar *name)
 {
 	gint rc;
 	gchar *sql;
@@ -1339,6 +1491,89 @@ get_mysql_tables (GdaConnection *cnc, GdaParameterList *params)
 	return model;
 }
 
+static GdaDataModel *
+get_mysql_views (GdaConnection *cnc, GdaParameterList *params)
+{
+	GList *reclist;
+	GdaMysqlRecordset *recset;
+	GdaDataModel *model;
+	gint rows, r;
+
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
+
+	/* add the extra information */
+	model = gda_data_model_array_new (4);
+	gda_data_model_set_column_title (model, 0, _("Name"));
+	gda_data_model_set_column_title (model, 1, _("Owner"));
+	gda_data_model_set_column_title (model, 2, _("Comments"));
+	gda_data_model_set_column_title (model, 3, "SQL");
+
+	/* views are not yet supported in MySql => return an empty set */
+
+	return model;
+}
+
+static GdaDataModel *
+get_mysql_procedures (GdaConnection *cnc, GdaParameterList *params)
+{
+	GList *reclist;
+	GdaDataModel *model;
+	gint rows, r;
+	gint i;
+
+	struct {
+		const gchar *name;
+		const gchar *id;
+		/*const gchar *owner; "" */
+		const gchar *comments;
+		const gchar *rettype;
+		gint         nb_args;
+		const gchar *argtypes;
+		/*const gchar *definition; NULL */
+	} procs[] = {
+		{ "ascii", "ascii", "", "smallint", 1, "text"},
+		{ "bin", "bin", "", "text", 1, "bigint"},
+		{ "bit_length", "bit_length", "", "int", 1, "text"},
+		{ "char", "char", "", "text", -1, "-"}
+	};
+
+
+	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
+
+	/* add the extra information */
+	model = gda_data_model_array_new (8);
+	gda_data_model_set_column_title (model, 0, _("Procedure"));
+	gda_data_model_set_column_title (model, 1, _("Id"));
+	gda_data_model_set_column_title (model, 2, _("Owner"));
+	gda_data_model_set_column_title (model, 3, _("Comments"));
+	gda_data_model_set_column_title (model, 4, _("Return type"));
+	gda_data_model_set_column_title (model, 5, _("Nb args"));
+	gda_data_model_set_column_title (model, 6, _("Args types"));
+	gda_data_model_set_column_title (model, 7, _("Definition"));
+
+	/* fill the recordset */
+	for (i = 0; i < sizeof (procs) / sizeof (procs[0]); i++) {
+		GList *value_list = NULL;
+
+		value_list = g_list_append (value_list, gda_value_new_string (procs[i].name));
+		value_list = g_list_append (value_list, gda_value_new_string (procs[i].id));
+		value_list = g_list_append (value_list, gda_value_new_string (""));
+		value_list = g_list_append (value_list, gda_value_new_string (procs[i].comments));
+		value_list = g_list_append (value_list, gda_value_new_string (procs[i].rettype));
+		value_list = g_list_append (value_list, gda_value_new_integer (procs[i].nb_args));
+		value_list = g_list_append (value_list, gda_value_new_string (procs[i].argtypes));
+		value_list = g_list_append (value_list, gda_value_new_string (NULL));
+
+		gda_data_model_append_values (GDA_DATA_MODEL (model), value_list);
+
+		g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
+		g_list_free (value_list);
+	}
+
+	return model;
+}
+
+
 static GdaDataModel *
 get_mysql_types (GdaConnection *cnc, GdaParameterList *params)
 {
@@ -1349,45 +1584,54 @@ get_mysql_types (GdaConnection *cnc, GdaParameterList *params)
 		const gchar *owner;
 		const gchar *comments;
 		GdaValueType type;
+		const gchar *synonyms;
 	} types[] = {
-		{ "blob", "", "Binary blob", GDA_VALUE_TYPE_BINARY },
-		{ "bigint", "", "Big integer", GDA_VALUE_TYPE_BIGINT },
-		{ "char", "", "Char", GDA_VALUE_TYPE_STRING },
-		{ "date", "", "Date", GDA_VALUE_TYPE_DATE },
-		{ "datetime", "", "Date and time", GDA_VALUE_TYPE_TIMESTAMP },
-		{ "decimal", "", "Decimal number", GDA_VALUE_TYPE_DOUBLE },
-		{ "double", "", "Double precision number", GDA_VALUE_TYPE_DOUBLE },
-		{ "enum", "", "Enumeration", GDA_VALUE_TYPE_STRING },
-		{ "float", "", "Single precision number", GDA_VALUE_TYPE_SINGLE },
-		{ "int", "", "Integer", GDA_VALUE_TYPE_INTEGER },
-		{ "integer", "", "Integer", GDA_VALUE_TYPE_INTEGER },		
-		{ "long", "", "Long integer", GDA_VALUE_TYPE_INTEGER },
-		{ "longblob", "", "Long blob", GDA_VALUE_TYPE_BINARY },
-		{ "longtext", "", "Long text", GDA_VALUE_TYPE_STRING },
-		{ "mediumint", "", "Medium integer", GDA_VALUE_TYPE_INTEGER },
-		{ "mediumblob", "", "Medium blob", GDA_VALUE_TYPE_BINARY },
-		{ "mediumtext", "", "Medium text", GDA_VALUE_TYPE_STRING },				
-		{ "set", "", "Set", GDA_VALUE_TYPE_STRING },
-		{ "smallint", "", "Small integer", GDA_VALUE_TYPE_INTEGER },
-		{ "text", "", "Text", GDA_VALUE_TYPE_STRING },
-		{ "tinyint", "", "Tiny integer", GDA_VALUE_TYPE_INTEGER }, /* really a boolean */
-		{ "tinyblob", "", "Tiny blob", GDA_VALUE_TYPE_BINARY },
-		{ "tinytext", "", "Tiny text", GDA_VALUE_TYPE_STRING },		
-		{ "time", "", "Time", GDA_VALUE_TYPE_TIME },
-		{ "timestamp", "", "Time stamp", GDA_VALUE_TYPE_TIMESTAMP },
-		{ "varchar", "", "Variable Length Char", GDA_VALUE_TYPE_STRING },
-		{ "year", "", "Year", GDA_VALUE_TYPE_INTEGER }
+		{ "bool", "", "Boolean type", GDA_VALUE_TYPE_BINARY, "boolean" },
+		{ "blob", "", "Binary blob (up to 65535 bytes)", GDA_VALUE_TYPE_BINARY, NULL },
+		{ "bigint", "", "Big integer, range is -9223372036854775808 to 9223372036854775807", GDA_VALUE_TYPE_BIGINT, NULL  },
+		{ "bigint unsigned", "", "Big unsigned integer, range is 0 to 18446744073709551615", GDA_VALUE_TYPE_BIGINT, NULL  },
+		{ "char", "", "Char", GDA_VALUE_TYPE_STRING, "binary"  },
+		{ "date", "", "Date", GDA_VALUE_TYPE_DATE, NULL  },
+		{ "datetime", "", "Date and time", GDA_VALUE_TYPE_TIMESTAMP, NULL  },
+		{ "decimal", "", "Decimal number", GDA_VALUE_TYPE_DOUBLE, "dec,numeric,fixed"  },
+		{ "double", "", "Double precision number", GDA_VALUE_TYPE_DOUBLE, "double precision,real"  },
+		{ "double unsigned", "", "Unsigned double precision number", GDA_VALUE_TYPE_DOUBLE, "double precision unsigned,real unsigned"  },
+		{ "enum", "", "Enumeration: a string object that can have only one value, chosen from the list of values 'value1', 'value2', ..., NULL or the special '' error value. An ENUM column can have a maximum of 65,535 distinct values", GDA_VALUE_TYPE_STRING, NULL  },
+		{ "float", "", "Floating point number", GDA_VALUE_TYPE_SINGLE , NULL },
+		{ "float unsigned", "", "Unsigned floating point number", GDA_VALUE_TYPE_SINGLE , NULL },
+		{ "int", "", "Integer, range is -2147483648 to 2147483647", GDA_VALUE_TYPE_INTEGER, "integer"  },
+		{ "int unsigned", "", "Unsigned integer, range is 0 to 4294967295", GDA_VALUE_TYPE_UINTEGER, "integer unsigned"  },
+		{ "long", "", "Long integer", GDA_VALUE_TYPE_INTEGER, NULL  },
+		{ "longblob", "", "Long blob (up to 4Gb)", GDA_VALUE_TYPE_BINARY, NULL  },
+		{ "longtext", "", "Long text (up to 4Gb characters)", GDA_VALUE_TYPE_STRING, NULL  },
+		{ "mediumint", "", "Medium integer, range is -8388608 to 8388607", GDA_VALUE_TYPE_INTEGER, NULL  },
+		{ "mediumint unsigned", "", "Medium unsigned integer, range is 0 to 16777215", GDA_VALUE_TYPE_INTEGER, NULL  },
+		{ "mediumblob", "", "Medium blob (up to 16777215 bytes)", GDA_VALUE_TYPE_BINARY, NULL  },
+		{ "mediumtext", "", "Medium text (up to 16777215 characters)", GDA_VALUE_TYPE_STRING, NULL  },				
+		{ "set", "", "Set: a string object that can have zero or more values, each of which must be chosen from the list of values 'value1', 'value2', ... A SET column can have a maximum of 64 members", GDA_VALUE_TYPE_STRING, NULL  },
+		{ "smallint", "", "Small integer, range is -32768 to 32767", GDA_VALUE_TYPE_SMALLINT, NULL  },
+		{ "smallint unsigned", "", "Small unsigned integer, range is 0 to 65535", GDA_VALUE_TYPE_SMALLINT, NULL  },
+		{ "text", "", "Text (up to 65535 characters)", GDA_VALUE_TYPE_STRING, NULL  },
+		{ "tinyint", "", "Tiny integer, range is -128 to 127", GDA_VALUE_TYPE_TINYINT, NULL  },
+		{ "tinyint unsigned", "", "Tiny unsigned integer, range is 0 to 255", GDA_VALUE_TYPE_TINYUINT, NULL  },
+		{ "tinyblob", "", "Tiny blob (up to 255 bytes)", GDA_VALUE_TYPE_BINARY, NULL  },
+		{ "tinytext", "", "Tiny text (up to 255 characters)", GDA_VALUE_TYPE_STRING, NULL  },		
+		{ "time", "", "Time", GDA_VALUE_TYPE_TIME, NULL  },
+		{ "timestamp", "", "Time stamp", GDA_VALUE_TYPE_TIMESTAMP, NULL  },
+		{ "varchar", "", "Variable Length Char", GDA_VALUE_TYPE_STRING, "varbinary"  },
+		{ "year", "", "Year", GDA_VALUE_TYPE_INTEGER, NULL  }
 	};
 
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
 
 	/* create the recordset */
-	recset = (GdaDataModelArray *) gda_data_model_array_new (4);
+	recset = (GdaDataModelArray *) gda_data_model_array_new (5);
 	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 0, _("Type"));
 	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 1, _("Owner"));
 	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 2, _("Comments"));
 	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 3, _("GDA type"));
-
+	gda_data_model_set_column_title (GDA_DATA_MODEL (recset), 4, _("Synonyms"));
+	
 	/* fill the recordset */
 	for (i = 0; i < sizeof (types) / sizeof (types[0]); i++) {
 		GList *value_list = NULL;
@@ -1396,6 +1640,7 @@ get_mysql_types (GdaConnection *cnc, GdaParameterList *params)
 		value_list = g_list_append (value_list, gda_value_new_string (types[i].owner));
 		value_list = g_list_append (value_list, gda_value_new_string (types[i].comments));
 		value_list = g_list_append (value_list, gda_value_new_type (types[i].type));
+		value_list = g_list_append (value_list, gda_value_new_string (types[i].synonyms));
 
 		gda_data_model_append_values (GDA_DATA_MODEL (recset), value_list);
 
@@ -1458,11 +1703,17 @@ field_row_to_value_list (MYSQL_ROW mysql_row)
 	value_list = g_list_append (value_list, gda_value_new_boolean (FALSE));
 
 	/* references */
-	value_list = g_list_append (value_list, gda_value_new_string (mysql_row[5]));
+	value_list = g_list_append (value_list, gda_value_new_string (""));
 
 	/* default value */
 	value_list = g_list_append (value_list, gda_value_new_string (mysql_row[4]));
 
+	/* Extra column */
+	if (!strcmp (mysql_row[5], "auto_increment"))
+		value_list = g_list_append (value_list, gda_value_new_string ("AUTO_INCREMENT"));
+	else
+		value_list = g_list_append (value_list, gda_value_new_string (""));
+
 	return value_list;
 }
 
@@ -1489,7 +1740,8 @@ get_table_fields (GdaConnection *cnc, GdaParameterList *params)
 		{ N_("Primary key?")	, GDA_VALUE_TYPE_BOOLEAN },
 		{ N_("Unique index?")	, GDA_VALUE_TYPE_BOOLEAN },
 		{ N_("References")	, GDA_VALUE_TYPE_STRING  },
-		{ N_("Default value")   , GDA_VALUE_TYPE_STRING  }
+		{ N_("Default value")   , GDA_VALUE_TYPE_STRING  },
+		{ N_("Extra attributes"), GDA_VALUE_TYPE_STRING  }
 	};
 
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
@@ -1599,8 +1851,12 @@ gda_mysql_provider_get_schema (GdaServerProvider *provider,
 		return get_table_fields (cnc, params);
 	case GDA_CONNECTION_SCHEMA_TABLES :
 		return get_mysql_tables (cnc, params);
+	case GDA_CONNECTION_SCHEMA_VIEWS:
+		return get_mysql_views (cnc, params);
 	case GDA_CONNECTION_SCHEMA_TYPES :
 		return get_mysql_types (cnc, params);
+	case GDA_CONNECTION_SCHEMA_PROCEDURES:
+		return get_mysql_procedures (cnc, params);
 	default : break;
 	}
 
